@@ -1,8 +1,8 @@
 #!/home/ben/software/install/bin/perl
 use warnings;
 use strict;
-use Gzip::Zopfli 'ZopfliCompress';
+use Gzip::Zopfli 'zopfli_compress';
 my $in = 'something' x 1000;
-my $out = ZopfliCompress ($in);
+my $out = zopfli_compress ($in);
 print length ($out), ' ', length ($in), "\n";
 
